@@ -2,15 +2,14 @@
 
 /* 
  * LDAPObject - wrapper around an LDAP* context
- * $Id: LDAPObject.c,v 1.76 2006/11/15 16:31:24 stroeder Exp $
+ * $Id: LDAPObject.c,v 1.78 2006/12/06 07:36:00 stroeder Exp $
  */
 
-#include "Python.h"
+#include "common.h"
 #include "patchlevel.h"
 
 #include <math.h>
 #include <limits.h>
-#include "common.h"
 #include "errors.h"
 #include "constants.h"
 #include "LDAPObject.h"
@@ -79,7 +78,7 @@ not_valid( LDAPObject* l ) {
 static void
 LDAPMod_DEL( LDAPMod* lm )
 {
-    int i;
+    Py_ssize_t i;
 
     if (lm->mod_type)
 	PyMem_DEL(lm->mod_type);
@@ -111,7 +110,7 @@ Tuple_to_LDAPMod( PyObject* tup, int no_op )
     char *type;
     PyObject *list, *item;
     LDAPMod *lm = NULL;
-    int i, len, nstrs;
+    Py_ssize_t i, len, nstrs;
 
     if (!PyTuple_Check(tup)) {
 	PyErr_SetObject(PyExc_TypeError, Py_BuildValue("sO",
@@ -210,7 +209,7 @@ LDAPMods_DEL( LDAPMod** lms ) {
 static LDAPMod**
 List_to_LDAPMods( PyObject *list, int no_op ) {
 
-    int i, len;
+    Py_ssize_t i, len;
     LDAPMod** lms;
     PyObject *item;
 
@@ -263,7 +262,7 @@ int
 attrs_from_List( PyObject *attrlist, char***attrsp ) {
 
     char **attrs = NULL;
-    int i, len;
+    Py_ssize_t i, len;
     PyObject *item;
 
     if (attrlist == Py_None) {
@@ -466,7 +465,7 @@ l_ldap_simple_bind( LDAPObject* self, PyObject* args )
     char *who;
     int msgid;
     int ldaperror;
-    int cred_len;
+    Py_ssize_t cred_len;
     PyObject *serverctrls = Py_None;
     PyObject *clientctrls = Py_None;
     LDAPControl** server_ldcs = NULL;
@@ -703,6 +702,53 @@ l_ldap_sasl_interactive_bind_s( LDAPObject* self, PyObject* args )
 }
 #endif
 
+
+#ifdef LDAP_API_FEATURE_CANCEL
+
+/* ldap_cancel */
+
+static PyObject*
+l_ldap_cancel( LDAPObject* self, PyObject* args )
+{
+    int msgid;
+    int cancelid;
+    PyObject *serverctrls = Py_None;
+    PyObject *clientctrls = Py_None;
+    LDAPControl** server_ldcs = NULL;
+    LDAPControl** client_ldcs = NULL;
+
+    int ldaperror;
+
+    if (!PyArg_ParseTuple( args, "i|OO", &cancelid, &serverctrls, &clientctrls)) return NULL;
+    if (not_valid(self)) return NULL;
+
+    if (!PyNone_Check(serverctrls)) {
+        server_ldcs = List_to_LDAPControls(serverctrls);
+        if (server_ldcs == NULL)
+            return NULL;
+    }
+
+    if (!PyNone_Check(clientctrls)) {
+        client_ldcs = List_to_LDAPControls(clientctrls);
+        if (client_ldcs == NULL)
+            return NULL;
+    }
+
+    LDAP_BEGIN_ALLOW_THREADS( self );
+    ldaperror = ldap_cancel( self->ldap, cancelid, server_ldcs, client_ldcs, &msgid );
+    LDAP_END_ALLOW_THREADS( self );
+
+    LDAPControl_List_DEL( server_ldcs );
+    LDAPControl_List_DEL( client_ldcs );
+
+    if ( ldaperror!=LDAP_SUCCESS )
+    	return LDAPerror( self->ldap, "ldap_cancel" );
+
+    return PyInt_FromLong( msgid );
+}
+
+#endif
+
 /* ldap_compare_ext */
 
 static PyObject *
@@ -716,7 +762,7 @@ l_ldap_compare_ext( LDAPObject* self, PyObject *args )
 
     int msgid;
     int ldaperror;
-    int value_len;
+    Py_ssize_t value_len;
     struct berval value;
 
     if (!PyArg_ParseTuple( args, "sss#|OO", &dn, &attr, &value.bv_val, &value_len, &serverctrls, &clientctrls )) return NULL;
@@ -1166,11 +1212,11 @@ static PyObject *
 l_ldap_passwd( LDAPObject* self, PyObject *args )
 {
     struct berval user;
-    int user_len;
+    Py_ssize_t user_len;
     struct berval oldpw;
-    int oldpw_len;
+    Py_ssize_t oldpw_len;
     struct berval newpw;
-    int newpw_len;
+    Py_ssize_t newpw_len;
     PyObject *serverctrls = Py_None;
     PyObject *clientctrls = Py_None;
     LDAPControl** server_ldcs = NULL;
@@ -1244,6 +1290,9 @@ static PyMethodDef methods[] = {
     {"get_option",	(PyCFunction)l_ldap_get_option,		METH_VARARGS },
 #if defined(FILENO_SUPPORTED)
     {"fileno",		(PyCFunction)l_ldap_fileno,		METH_VARARGS },
+#endif
+#ifdef LDAP_API_FEATURE_CANCEL
+    {"cancel",		(PyCFunction)l_ldap_cancel,		METH_VARARGS },
 #endif
     { NULL, NULL }
 };
@@ -1253,12 +1302,6 @@ static PyMethodDef methods[] = {
 static PyObject*
 getattr(LDAPObject* self, char* name) 
 {
-	int option;
-
-	option = LDAP_optionval_by_name(name);
-	if (option != -1)
-		return LDAP_get_option(self, option);
-
 	return Py_FindMethod(methods, (PyObject*)self, name);
 }
 
@@ -1267,12 +1310,6 @@ getattr(LDAPObject* self, char* name)
 static int
 setattr(LDAPObject* self, char* name, PyObject* value) 
 {
-	int option;
-
-	option = LDAP_optionval_by_name(name);
-	if (option != -1)
-		return LDAP_set_option(self, option, value);
-
 	PyErr_SetString(PyExc_AttributeError, name);
 	return -1;
 }
