@@ -2,14 +2,16 @@
 /*
  * common utility macros
  *
- * $Id: common.h,v 1.4 2004/10/06 21:26:07 stroeder Exp $ 
+ * $Id: common.h,v 1.6 2006/12/06 07:36:00 stroeder Exp $ 
  */
 
-#include "Python.h"
-
 #ifndef __h_common 
 #define __h_common 
 
+#define PY_SSIZE_T_CLEAN
+
+#include "Python.h"
+
 #if defined(HAVE_CONFIG_H)
 #include "config.h"
 #endif
@@ -22,6 +24,13 @@
 #include <sys/types.h>
 #endif
 
+/* Backwards compability with Python prior 2.5 */
+#if PY_VERSION_HEX < 0x02050000
+typedef int Py_ssize_t;
+#define PY_SSIZE_T_MAX INT_MAX
+#define PY_SSIZE_T_MIN INT_MIN
+#endif
+
 #include <string.h>
 #define streq( a, b ) \
 	( (*(a)==*(b)) && 0==strcmp(a,b) )
