@@ -2,9 +2,9 @@
 #ifndef __h_constants_
 #define __h_constants_
 
-/* $Id: constants.h,v 1.2 2005/06/14 17:49:14 stroeder Exp $ */
+/* $Id: constants.h,v 1.4 2007/07/16 10:49:48 stroeder Exp $ */
 
-#include "Python.h"
+#include "common.h"
 extern void LDAPinit_constants( PyObject* d );
 extern PyObject* LDAPconstant( int );
 
@@ -12,4 +12,8 @@ extern PyObject* LDAPconstant( int );
 #define LDAP_CONTROL_PAGE_OID "1.2.840.113556.1.4.319"
 #endif /* !LDAP_CONTROL_PAGE_OID */
 
+#ifndef LDAP_CONTROL_VALUESRETURNFILTER
+#define LDAP_CONTROL_VALUESRETURNFILTER "1.2.826.0.1.3344810.2.3" /* RFC 3876 */
+#endif /* !LDAP_CONTROL_VALUESRETURNFILTER */
+
 #endif /* __h_constants_ */
